# Inbound Processors
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#overview)
  * [Types of Inbound Data Processors](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#types-of-inbound-data-processors)
  * [Execution of the Started iAPI Runs](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#execution-of-the-started-iapi-runs)
  * [General Structure](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#general-structure)
  * [Inbound Fact Sheet](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#inbound-fact-sheet)
  * [Lifecycle Management](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#lifecycle-management)
  * [Location Management](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#location-management)
  * [Inbound Subscription](https://help.sap.com/docs/leanix/ea/inbound-processors?version=CLOUD#inbound-subscription)


View all
